yyjson_merge_patch

Function yyjson_merge_patch 

pub unsafe extern "C" fn yyjson_merge_patch(
    doc: *mut yyjson_mut_doc,
    orig: *mut yyjson_val,
    patch: *mut yyjson_val,
) -> *mut yyjson_mut_val
Creates and returns a merge-patched JSON value (RFC 7386). The memory of the returned value is allocated by the doc. Returns NULL if the patch could not be applied.

@warning This function is recursive and may cause a stack overflow if the object level is too deep.