pub unsafe extern "C" fn yyjson_patch(
doc: *mut yyjson_mut_doc,
orig: *mut yyjson_val,
patch: *mut yyjson_val,
err: *mut yyjson_patch_err,
) -> *mut yyjson_mut_valExpand description
Creates and returns a patched JSON value (RFC 6902).
The memory of the returned value is allocated by the doc.
The err is used to receive error information, pass NULL if not needed.
Returns NULL if the patch could not be applied.